defmodule PrymnWeb.ServerLive.Index do
  use PrymnWeb, :live_view

  alias Prymn.Servers

  @impl true
  def mount(_params, _session, socket) do
    {:ok, stream(socket, :servers, Servers.list_servers())}
  end

  @impl true
  def handle_params(params, _url, socket) do
    {:noreply, apply_action(socket, socket.assigns.live_action, params)}
  end

  defp apply_action(socket, :new, _params) do
    socket
    |> assign(:page_title, "New Server")
  end

  defp apply_action(socket, :index, _params) do
    socket
    |> assign(:page_title, "Listing Servers")
  end

  @impl true
  def handle_info({:connect, server}, socket) do
    # TODO: Connect the new server:
    #       For custom connections: will need to generate a new prompt for the user to execute
    #       For API connections: the "prompt" will be automatic, but same execution server-side
    {:noreply, stream_insert(socket, :servers, server)}
  end

  @impl true
  def handle_event("delete", %{"id" => id}, socket) do
    server = Servers.get_server!(id)
    {:ok, _} = Servers.delete_server(server)

    {:noreply, stream_delete(socket, :servers, server)}
  end
end
